#!/bin/bash

#$1 - file-name

set -e

if [ $# -ne 1 ]; then
  echo "Usage: $0 <file-name>"
  exit 1
fi

FILE_NAME=$1.tar.gz
DIR=saved_files

#clean up before we start
cd /tmp;
/bin/rm -rf $DIR *.tar.gz 2> /dev/null
cd - > /dev/null

mkdir -p /tmp/$DIR/cores
mkdir -p /tmp/$DIR/other/additional_logs
mkdir -p /tmp/$DIR/tcrcli
mkdir -p /tmp/$DIR/telegraf


function copy_files {
  TCR_DIR=`basename $1`;
  mkdir -p /tmp/$DIR/$TCR_DIR
  
  #copy configuration files
  /bin/cp -r /opt/$TCR_DIR/{tcr.conf,tcr_conf_active.json,tcr_conf_passive.json,tdns_persistent.txt} /tmp/$DIR/$TCR_DIR 2>/dev/null || :;
  /bin/cp -r /opt/$TCR_DIR/wanproxy/wanproxy.conf /tmp/$DIR/$TCR_DIR 2>/dev/null || :;

  #copy iptables and ipset files
  /bin/cp -r /opt/$TCR_DIR/{ipset_set,iptables_set,tcr_rules} /tmp/$DIR/$TCR_DIR 2>/dev/null || :;
  
  #copy all logs 
  /bin/cp -r /var/log/$TCR_DIR/*.log* /tmp/$DIR/$TCR_DIR 2> /dev/null || :;
  
  #copy wanproxy core dumps files
  /bin/cp -r /opt/$TCR_DIR/wanproxy/var/log/* /tmp/$DIR/$TCR_DIR 2> /dev/null || :;

  #delete empty folders
  find /tmp/$DIR/$TCR_DIR/ -type d -empty -delete 2>/dev/null || :;
}

#loop through all TCR folders in /opt/
for f in /opt/*;
do
  if [[ -d "$f" && ! -L "$f" ]];
  then
    if [[ ${f} == /opt/tcr-* ]];
    then
	    copy_files $f;
    fi	
  fi
done

#copy core dump files
/bin/cp /var/log/core.* /tmp/$DIR/cores 2> /dev/null || :;
/bin/cp /var/crash/*.txt /tmp/$DIR/cores 2> /dev/null || :;
/bin/cp /var/log/tcr_cleaner.log* /tmp/$DIR/other 2> /dev/null || :;

#gre persistency file
/bin/cp /etc/tcr_gre_sites_persist.json /tmp/$DIR/other 2>/dev/null || :;

#additional outputs folder
/bin/cp /var/log/additional_logs/* /tmp/$DIR/other/additional_logs 2> /dev/null || :;

#copy system logs
/bin/cp /var/log/{dmesg*,messages*,secure*,yum.log*,pluto*,bird*,gred*} /tmp/$DIR/other 2> /dev/null || :;

#mask customer ips
mask=`tcr_cli show General.mask_client_address | awk '{print $3;}' | sed '$s/.$//'`
if [[ "${mask}" == "true" ]];
then
  ls -d /tmp/$DIR/other/pluto* | xargs sed -i -e '/\@Customer/s/\(\([0-9]\{1,3\}\.\)\{3\}\)[0-9]\{1,3\}/\1XXX/g' || :;
fi

#copy ops logs
/bin/cp /var/log/tcrcli/tcr_cli.log* /tmp/$DIR/tcrcli 2> /dev/null || :;
/bin/cp /var/log/telegraf/telegraf.log* /tmp/$DIR/telegraf 2> /dev/null || :;

#create tar.gz file
cd /tmp;
/bin/tar czf $FILE_NAME $DIR/  2> /dev/null

#clean up
/bin/rm -rf $DIR 2> /dev/null
